@@ -176,6 +176,15 @@ pub struct ArrayLit {
     pub elems: Vec<Option<ExprOrSpread>>,
 }
 
+impl Take for ArrayLit {
+    fn dummy() -> Self {
+        ArrayLit {
+            span: DUMMY_SP,
+            elems: Default::default(),
+        }
+    }
+}
+
 /// Object literal.
 #[ast_node("ObjectExpression")]
 #[derive(Eq, Hash, EqIgnoreSpan)]
@@ -187,6 +196,15 @@ pub struct ObjectLit {
     pub props: Vec<PropOrSpread>,
 }
 
+impl Take for ObjectLit {
+    fn dummy() -> Self {
+        ObjectLit {
+            span: DUMMY_SP,
+            props: Default::default(),
+        }
+    }
+}
+
 #[ast_node]
 #[derive(Eq, Hash, Is, EqIgnoreSpan)]
 #[cfg_attr(feature = "arbitrary", derive(arbitrary::Arbitrary))]
