@@ -8,7 +8,7 @@ use crate::{
     typescript::TsTypeAnn,
 };
 use is_macro::Is;
-use swc_common::{ast_node, EqIgnoreSpan, Span};
+use swc_common::{ast_node, util::take::Take, EqIgnoreSpan, Span};
 
 #[ast_node]
 #[derive(Eq, Hash, Is, EqIgnoreSpan)]
@@ -107,6 +107,12 @@ pub enum PropName {
     BigInt(BigInt),
 }
 
+impl Take for PropName {
+    fn dummy() -> Self {
+        PropName::Ident(Take::dummy())
+    }
+}
+
 #[ast_node("Computed")]
 #[derive(Eq, Hash, EqIgnoreSpan)]
 #[cfg_attr(feature = "arbitrary", derive(arbitrary::Arbitrary))]
