@@ -5,7 +5,7 @@ use crate::{
     pat::Pat,
 };
 use is_macro::Is;
-use swc_common::{ast_node, EqIgnoreSpan, Span};
+use swc_common::{ast_node, util::take::Take, EqIgnoreSpan, Span, DUMMY_SP};
 
 /// Use when only block statements are allowed.
 #[ast_node("BlockStatement")]
@@ -18,6 +18,15 @@ pub struct BlockStmt {
     pub stmts: Vec<Stmt>,
 }
 
+impl Take for BlockStmt {
+    fn dummy() -> Self {
+        BlockStmt {
+            span: DUMMY_SP,
+            stmts: vec![],
+        }
+    }
+}
+
 #[ast_node]
 #[derive(Eq, Hash, Is, EqIgnoreSpan)]
 #[cfg_attr(feature = "arbitrary", derive(arbitrary::Arbitrary))]
@@ -94,6 +103,12 @@ pub enum Stmt {
     Expr(ExprStmt),
 }
 
+impl Take for Stmt {
+    fn dummy() -> Self {
+        Self::Empty(EmptyStmt { span: DUMMY_SP })
+    }
+}
+
 #[ast_node("ExpressionStatement")]
 #[derive(Eq, Hash, EqIgnoreSpan)]
 #[cfg_attr(feature = "arbitrary", derive(arbitrary::Arbitrary))]
